<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Businesszen
 * @since Businesszen 1.0.0
 * @return array An array of default values
 */

function businesszen_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$businesszen_default_options = array(
		// Color Options
		'header_title_color'			=> '#000',
		'header_tagline_color'			=> '#000',
		'header_txt_logo_extra'			=> 'show-all',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',

		//body typography
		'body_font_family'			=> 'Muli',
		'body_font_weight'			=> 300,
		'body_font_size'			=> 16,
		'body_font_style'			=> 'normal',
		'body_text_transform'		=> 'none',

		//h1 typography
		'heading_h1_font_family'		=> 'Raleway',
		'heading_h1_font_weight'		=> 300,
		'heading_h1_text_transform'		=> 'none',
		'heading_h1_font_style'			=> 'normal',

		//h2 typography
		'heading_h2_font_family'		=> 'Raleway',
		'heading_h2_font_weight'		=> 700,
		'heading_h2_text_transform'		=> 'none',
		'heading_h2_font_style'			=> 'normal',

		//h3 typography
		'heading_h3_font_family'		=> 'Raleway',
		'heading_h3_font_weight'		=> 700,
		'heading_h3_text_transform'		=> 'none',
		'heading_h3_font_style'			=> 'normal',

		//h4 typography
		'heading_h4_font_family'		=> 'Raleway',
		'heading_h4_font_weight'		=> 700,
		'heading_h4_text_transform'		=> 'none',
		'heading_h4_font_style'			=> 'normal',

		//h5 typography
		'heading_h5_font_family'		=> 'Raleway',
		'heading_h5_font_weight'		=> 700,
		'heading_h5_text_transform'		=> 'none',
		'heading_h5_font_style'			=> 'normal',

		//h6 typography
		'heading_h6_font_family'		=> 'Raleway',
		'heading_h6_font_weight'		=> 700,
		'heading_h6_text_transform'		=> 'none',
		'heading_h6_font_style'			=> 'normal',

		//p typography
		'heading_p_font_family'			=> 'Muli',
		'heading_p_font_weight'			=> 400,
		'heading_p_text_transform'		=> 'none',
		'heading_p_font_style'			=> 'normal',

		//button
		'button_background_color'		=> '#e5f8fc',
		'button_text_color'		=> '#00afe9',
	
		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'businesszen' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		'all_sortable'					=> 'slider,about,service,cta,team,features,latest_posts,contact',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'businesszen' ),
		'single_post_hide_banner'		=> false,
		'hide_banner'					=> false,		
		'blog_page_column'				=> 'col-2',

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_content'		=> false,

		/* Front Page */

		//topbar
		'topbar_section_enable'			=> false,
		'topbar_social_menu_enable'		=> true,
		'topbar_no'						=> esc_html__( '+1 23 - 456 - 7890', 'businesszen' ),
		'topbar_email'					=> esc_html__( 'support@gmail.com', 'businesszen' ),
		'topbar_location'				=> esc_html__( 'United States of America', 'businesszen' ),

		// Slider
		'slider_section_enable'		=> false,
		'slider_btn_label'			=> esc_html__( 'Learn More', 'businesszen' ),

		// about
		'about_section_enable'			=> false,
		'about_subtitle'				=> esc_html__( 'About Us', 'businesszen' ),
		'about_btn_title'				=> esc_html__( 'Learn More', 'businesszen' ),

		// service
		'service_section_enable'		=> false,
		'service_sub_title'				=> esc_html('Our Services', 'businesszen'),
		'service_title'					=> esc_html('What We Offer', 'businesszen'),
		'service_btn'					=> esc_html('Learn More', 'businesszen'),

		// cta
		'cta_section_enable'			=> false,
		'cta_excerpt_length'			=> 30,

		// team
		'team_section_enable'		=> false,
		'team_sub_title'			=> esc_html('Our Team', 'businesszen'),
		'team_title'				=> esc_html('Professional Staffs', 'businesszen'),


		// features
		'features_section_enable'		=> false,
		'features_subtitle'				=> esc_html__( 'Our Features', 'businesszen' ),
		'features_title'				=> esc_html__( 'Grow Business Faster', 'businesszen' ),
		'features_btn_title'			=> esc_html__( 'Learn More', 'businesszen' ),

		//latest_posts
		'latest_posts_section_enable'	=> false,
		'latest_posts_content_type'		=> 'post',
		'latest_posts_sub_title'		=> esc_html__( 'Our Blog', 'businesszen' ),
		'latest_posts_title'			=> esc_html__( 'News & Announcement', 'businesszen' ),
		'latest_posts_btn_title'		=> esc_html__( 'View All Articles', 'businesszen' ),

		// contact
		'contact_section_enable'			=> false,
		'contact_section_subtitle'          => esc_html__('Contact Us','businesszen'),
		'contact_section_title'			    => esc_html__( 'Get Free SEO Analysis', 'businesszen' ),
		'contact_section_phone_number'	    => '+15 2589631471',
		'contact_section_address'			=> esc_html__( '8565 Avenue Street, United States', 'businesszen' ),
		'contact_section_email'			    => 'info@gmail.com',


	);

	$output = apply_filters( 'businesszen_default_theme_options', $businesszen_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}