<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Businesszen
 * @since Businesszen 1.0.0
 */

// Add About section
$wp_customize->add_section( 'businesszen_about_us_section', array(
	'title'             => esc_html__( 'About Us','businesszen' ),
	'description'       => esc_html__( 'About Us Section options.', 'businesszen' ),
	'panel'             => 'businesszen_front_page_panel',
	'priority'          => businesszen_about_section_theme_based_priority(),
) );

// About content enable control and setting
$wp_customize->add_setting( 'businesszen_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'businesszen_sanitize_switch_control',
) );

$wp_customize->add_control( new Businesszen_Switch_Control( $wp_customize, 'businesszen_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'businesszen' ),
	'section'           => 'businesszen_about_us_section',
	'on_off_label' 		=> businesszen_switch_options(),
) ) );

// about subtitle setting and control
$wp_customize->add_setting( 'businesszen_theme_options[about_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'businesszen_theme_options[about_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'businesszen' ),
	'section'        	=> 'businesszen_about_us_section',
	'active_callback' 	=> 'businesszen_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'businesszen_theme_options[about_subtitle]', array(
        'selector'            => '#businesszen_about_us_section p.section-subtitle',
        'settings'            => 'businesszen_theme_options[about_subtitle]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'businesszen_about_subtitle_partial',
    ) );
}

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'businesszen_theme_options[about_content_post]', array(
	'sanitize_callback' => 'businesszen_sanitize_page',
) );

$wp_customize->add_control( new Businesszen_Dropdown_Chooser( $wp_customize, 'businesszen_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'businesszen' ),
	'section'           => 'businesszen_about_us_section',
	'choices'			=> businesszen_post_choices(),
	'active_callback'	=> 'businesszen_is_about_section_enable',
) ) );

// about btn title setting and control
$wp_customize->add_setting( 'businesszen_theme_options[about_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'businesszen_theme_options[about_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'businesszen' ),
	'section'        	=> 'businesszen_about_us_section',
	'active_callback' 	=> 'businesszen_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'businesszen_theme_options[about_btn_title]', array(
		'selector'            => '#businesszen_about_us_section div.read-more a',
		'settings'            => 'businesszen_theme_options[about_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'businesszen_about_btn_title_partial',
    ) );
}