<?php
/**
 * CTA Section options
 *
 * @package Theme Palace
 * @subpackage Businesszen
 * @since Businesszen 1.0.0
 */

// Add CTA section
$wp_customize->add_section( 'businesszen_call_to_action_section', array(
	'title'             => esc_html__( 'CTA Section','businesszen' ),
	'description'       => esc_html__( 'CTA Section options.', 'businesszen' ),
	'panel'             => 'businesszen_front_page_panel',
	'priority'          => 50,
) );

// CTA content enable control and setting
$wp_customize->add_setting( 'businesszen_theme_options[cta_section_enable]', array(
	'default'			=> 	$options['cta_section_enable'],
	'sanitize_callback' => 'businesszen_sanitize_switch_control',
) );

$wp_customize->add_control( new Businesszen_Switch_Control( $wp_customize, 'businesszen_theme_options[cta_section_enable]', array(
	'label'             => esc_html__( 'CTA Section Enable', 'businesszen' ),
	'section'           => 'businesszen_call_to_action_section',
	'on_off_label' 		=> businesszen_switch_options(),
	'priority'          => 1,
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'businesszen_theme_options[cta_section_enable]', array(
		'selector'            => '#cta-section .tooltiptext',
		'settings'            => 'businesszen_theme_options[cta_section_enable]',
    ) );
}

// about image setting and control.
$wp_customize->add_setting( 'businesszen_theme_options[cta_image]', array(
	'sanitize_callback' => 'businesszen_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'businesszen_theme_options[cta_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'businesszen' ),
		'section'     		=> 'businesszen_call_to_action_section',
		'active_callback'	=> 'businesszen_is_cta_section_enable',
		'priority'          => 2,
) ) );

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'businesszen_theme_options[cta_content_page]', array(
	'sanitize_callback' => 'businesszen_sanitize_page',
) );

$wp_customize->add_control( new Businesszen_Dropdown_Chooser( $wp_customize, 'businesszen_theme_options[cta_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'businesszen' ),
	'section'           => 'businesszen_call_to_action_section',
	'choices'			=> businesszen_page_choices(),
	'active_callback'	=> 'businesszen_is_cta_section_enable',
	'priority'          => 3,
) ) );

	// about btn link setting and control
$wp_customize->add_setting( 'businesszen_theme_options[cta_video_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'businesszen_theme_options[cta_video_link]', array(
	'label'           	=> esc_html__( 'Video Link', 'businesszen' ),
	'section'        	=> 'businesszen_call_to_action_section',
	'active_callback' 	=> 'businesszen_is_cta_section_enable',
	'type'				=> 'url',
) );