<?php
/**
* Service Section options
*
* @package Theme Palace
* @subpackage Businesszen
* @since Businesszen 1.0.0
*/

// Add Service section
$wp_customize->add_section( 'businesszen_our_services_section', array(
	'title'             => esc_html__( 'Services','businesszen' ),
	'description'       => esc_html__( 'Services Section options.', 'businesszen' ),
	'panel'             => 'businesszen_front_page_panel',
	'priority'          => 40,
) );

// Service content enable control and setting
$wp_customize->add_setting( 'businesszen_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'businesszen_sanitize_switch_control',
	) );

$wp_customize->add_control( new Businesszen_Switch_Control( $wp_customize, 'businesszen_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'businesszen' ),
	'section'           => 'businesszen_our_services_section',
	'on_off_label' 		=> businesszen_switch_options(),
	'priority'          => 1,
	) ) );

// service title setting and control
	$wp_customize->add_setting( 'businesszen_theme_options[service_sub_title]',
		array(
			'default'       		=> $options['service_sub_title'],
			'sanitize_callback'		=> 'sanitize_text_field',
			'transport'				=> 'postMessage',
			)
		);
	$wp_customize->add_control( 'businesszen_theme_options[service_sub_title]',
		array(
			'label'      			=> esc_html__( 'Section Sub Title', 'businesszen' ),
			'section'    			=> 'businesszen_our_services_section',
			'type'		 			=> 'text',
			'active_callback'		=> 'businesszen_is_service_section_enable',
			'priority'              => 2,
			)
		);

// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'businesszen_theme_options[service_sub_title]', array(
			'selector'            => '#businesszen_our_services_section p.section-subtitle',
			'settings'            => 'businesszen_theme_options[service_sub_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'businesszen_service_sub_title_partial',
			) );
	}

// service title setting and control
	$wp_customize->add_setting( 'businesszen_theme_options[service_title]',
		array(
			'default'       		=> $options['service_title'],
			'sanitize_callback'		=> 'sanitize_text_field',
			'transport'				=> 'postMessage',
			)
		);
	$wp_customize->add_control( 'businesszen_theme_options[service_title]',
		array(
			'label'      			=> esc_html__( 'Section Title', 'businesszen' ),
			'section'    			=> 'businesszen_our_services_section',
			'type'		 			=> 'text',
			'active_callback'		=> 'businesszen_is_service_section_enable',
			'priority'              => 3,
			)
		);

// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'businesszen_theme_options[service_title]', array(
			'selector'            => '#businesszen_our_services_section h2.section-title',
			'settings'            => 'businesszen_theme_options[service_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'businesszen_service_title_partial',
			) );
	}

	// service title setting and control
	$wp_customize->add_setting( 'businesszen_theme_options[service_btn]',
		array(
			'default'       		=> $options['service_btn'],
			'sanitize_callback'		=> 'sanitize_text_field',
			)
		);
	$wp_customize->add_control( 'businesszen_theme_options[service_btn]',
		array(
			'label'      			=> esc_html__( 'Button Label', 'businesszen' ),
			'section'    			=> 'businesszen_our_services_section',
			'type'		 			=> 'text',
			'active_callback'		=> 'businesszen_is_service_section_enable',
			'priority'              => 4,
			)
		);

for ( $i = 1; $i <= (get_template_directory() !== get_stylesheet_directory() ? 3 : 6 ); $i++ ) :

// service note control and setting
	$wp_customize->add_setting( 'businesszen_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		) );

$wp_customize->add_control( new Businesszen_Icon_Picker( $wp_customize, 'businesszen_theme_options[service_content_icon_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Icon %d', 'businesszen' ), $i ),
	'section'           => 'businesszen_our_services_section',
	'active_callback'	=> 'businesszen_is_service_section_enable',
	'priority'          => $i + 4,
	) ) );

// service posts drop down chooser control and setting
$wp_customize->add_setting( 'businesszen_theme_options[service_content_post_' . $i . ']', array(
	'sanitize_callback' => 'businesszen_sanitize_page',
	) );

$wp_customize->add_control( new Businesszen_Dropdown_Chooser( $wp_customize, 'businesszen_theme_options[service_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'businesszen' ), $i ),
	'section'           => 'businesszen_our_services_section',
	'choices'			=> businesszen_post_choices(),
	'active_callback'	=> 'businesszen_is_service_section_enable',
	'priority'          => $i + 5,
	) ) );

endfor;