<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage Businesszen
 * @since Businesszen 1.0.0
 */

// Add Team section
$wp_customize->add_section( 'businesszen_our_team_section', array(
	'title'             => esc_html__( 'Teams','businesszen' ),
	'description'       => esc_html__( 'Teams Section options.', 'businesszen' ),
	'panel'             => 'businesszen_front_page_panel',
	'priority'          => 60,
) );

// Team content enable control and setting
$wp_customize->add_setting( 'businesszen_theme_options[team_section_enable]', array(
	'default'			=> 	$options['team_section_enable'],
	'sanitize_callback' => 'businesszen_sanitize_switch_control',
) );

$wp_customize->add_control( new Businesszen_Switch_Control( $wp_customize, 'businesszen_theme_options[team_section_enable]', array(
	'label'             => esc_html__( 'Team Section Enable', 'businesszen' ),
	'section'           => 'businesszen_our_team_section',
	'on_off_label' 		=> businesszen_switch_options(),
	'priority'          => 1,
) ) );

// team sub_title setting and control
$wp_customize->add_setting( 'businesszen_theme_options[team_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'businesszen_theme_options[team_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'businesszen' ),
	'section'        	=> 'businesszen_our_team_section',
	'active_callback' 	=> 'businesszen_is_team_section_enable',
	'type'				=> 'text',
	'priority'          => 2,
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'businesszen_theme_options[team_sub_title]', array(
		'selector'            => '#businesszen_our_team_section p.section-subtitle',
		'settings'            => 'businesszen_theme_options[team_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'businesszen_team_sub_title_partial',
    ) );
}

// team title setting and control
$wp_customize->add_setting( 'businesszen_theme_options[team_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'businesszen_theme_options[team_title]', array(
	'label'           	=> esc_html__( 'Title', 'businesszen' ),
	'section'        	=> 'businesszen_our_team_section',
	'active_callback' 	=> 'businesszen_is_team_section_enable',
	'type'				=> 'text',
	'priority'          => 3,
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'businesszen_theme_options[team_title]', array(
		'selector'            => '#businesszen_our_team_section h2.section-title',
		'settings'            => 'businesszen_theme_options[team_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'businesszen_team_title_partial',
    ) );
}

for ( $i = 1; $i <= 4; $i++ ) :

	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'businesszen_theme_options[team_content_page_' . $i . ']', array(
		'sanitize_callback' => 'businesszen_sanitize_page',
	) );

	$wp_customize->add_control( new Businesszen_Dropdown_Chooser( $wp_customize, 'businesszen_theme_options[team_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'businesszen' ), $i ),
		'section'           => 'businesszen_our_team_section',
		'choices'			=> businesszen_page_choices(),
		'active_callback'	=> 'businesszen_is_team_section_enable',
	) ) );

	// team custom content
	$wp_customize->add_setting( 'businesszen_theme_options[team_position_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'businesszen_theme_options[team_position_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Position %d', 'businesszen' ), $i ),
		'section'           => 'businesszen_our_team_section',
		'active_callback'	=> 'businesszen_is_team_section_enable',
	) );

	// team social
	$wp_customize->add_setting( 'businesszen_theme_options[team_social_' . $i. ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new Businesszen_Multi_Input_Custom_Control( $wp_customize, 'businesszen_theme_options[team_social_' . $i. ']', array(
		'label'             => esc_html__( 'Social ', 'businesszen' ),
		'button_text'       => esc_html__( 'Add social.', 'businesszen' ),
		'section'           => 'businesszen_our_team_section',
		'active_callback' 	=> 'businesszen_is_team_section_enable',
	) ) );

	// team hr setting and control
	$wp_customize->add_setting( 'businesszen_theme_options[team_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Businesszen_Customize_Horizontal_Line( $wp_customize, 'businesszen_theme_options[team_hr_'. $i .']',
		array(
			'section'         => 'businesszen_our_team_section',
			'active_callback' => 'businesszen_is_team_section_enable',
			'type'			  => 'hr',
	) ) );

endfor;