<?php
/**
 * Features section
 *
 * This is the template for the content of features section
 *
 * @package Theme Palace
 * @subpackage Businesszen
 * @since Businesszen 1.0.0
 */
if ( ! function_exists( 'businesszen_add_features_section' ) ) :
    /**
    * Add features section
    *
    *@since Businesszen 1.0.0
    */
    function businesszen_add_features_section() {
        $options = businesszen_get_theme_options();
        // Check if features is enabled on frontpage
        $features_enable = apply_filters( 'businesszen_section_status', true, 'features_section_enable' );

        if ( true !== $features_enable ) {
            return false;
        }
        // Get features section details
        $section_details = array();
        $section_details = apply_filters( 'businesszen_filter_features_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render features section now.
        businesszen_render_features_section( $section_details );
    }
endif;

if ( ! function_exists( 'businesszen_get_features_section_details' ) ) :
    /**
    * features section details.
    *
    * @since Businesszen 1.0.0
    * @param array $input features section details.
    */
    function businesszen_get_features_section_details( $input ) {
        $options = businesszen_get_theme_options();

        $content = array();
        $post_ids = array();

                for ( $i = 1; $i <= 2; $i++ ) {
                    if ( ! empty( $options['features_content_post_' . $i] ) )
                        $post_ids[] = $options['features_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( 2 ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = businesszen_trim_content( 30 );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// features section content details.
add_filter( 'businesszen_filter_features_section_details', 'businesszen_get_features_section_details' );


if ( ! function_exists( 'businesszen_render_features_section' ) ) :
  /**
   * Start features section
   *
   * @return string features content
   * @since Businesszen 1.0.0
   *
   */
   function businesszen_render_features_section( $content_details = array() ) {
        $options = businesszen_get_theme_options();
        $features_subtitle = !empty( $options['features_subtitle'] ) ? $options['features_subtitle'] : '';
        $features_title = !empty( $options['features_title'] ) ? $options['features_title'] : '';
 
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="businesszen_our_features_section" class="relative page-section">
            <div class="wrapper">
                <div class="section-header">
                    <?php if( !empty( $features_subtitle ) ): ?>
                        <p class="section-subtitle"><?php echo esc_html( $features_subtitle ); ?></p>
                    <?php endif;

                    if( !empty( $features_title ) ):
                        ?>
                    <h2 class="section-title"><?php echo esc_html( $features_title ); ?></h2>
                <?php endif; ?>
            </div><!-- .section-header -->

            <div class="section-content">

                <?php foreach ($content_details as $content): ?>

                    <article class="has-post-thumbnail">
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                        </div><!-- .featured-image -->

                        <div class="entry-container">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>">
                                    <?php echo esc_html( $content['title'] ); ?>
                                </a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->

                            <?php if( !empty( $options['features_btn_title'] ) ): ?>
                                <div class="read-more">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['features_btn_title'] ); ?></a>
                                </div>
                            <?php endif; ?>
                        </div><!-- .entry-container -->
                    </article>

                <?php endforeach; ?>

            </div><!-- .section-content -->
        </div><!-- .wrapper -->
    </div><!-- #businesszen_our_features_section -->   

    <?php }
endif;