<?php
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage Businesszen
 * @since Businesszen 1.0.0
 */
if ( ! function_exists( 'businesszen_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since Businesszen 1.0.0
    */
    function businesszen_add_slider_section() {
    	$options = businesszen_get_theme_options();
        // Check if slider is enabled on frontpage
        $slider_enable = apply_filters( 'businesszen_section_status', true, 'slider_section_enable' );

        if ( true !== $slider_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'businesszen_filter_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render slider section now.
        businesszen_render_slider_section( $section_details );
    }
endif;

if ( ! function_exists( 'businesszen_get_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since Businesszen 1.0.0
    * @param array $input slider section details.
    */
    function businesszen_get_slider_section_details( $input ) {
        $options = businesszen_get_theme_options();

        $content = array();
       $post_ids = array();

                for ( $i = 1; $i <= 3; $i++ ) {
                    if ( ! empty( $options['slider_content_post_' . $i] ) )
                        $post_ids[] = $options['slider_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( 3 ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = businesszen_trim_content( 30 );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'businesszen_filter_slider_section_details', 'businesszen_get_slider_section_details' );


if ( ! function_exists( 'businesszen_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since Businesszen 1.0.0
   *
   */
   function businesszen_render_slider_section( $content_details = array() ) {
        $options = businesszen_get_theme_options();
        $btn_label = ! empty( $options['slider_btn_label'] ) ? $options['slider_btn_label'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="businesszen_featured_slider_section" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1500, "dots": true, "arrows": true, "autoplay": false, "draggable": true, "fade": true }'>

            <?php $i = 1; foreach ($content_details as $content): ?>

            <article style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                <div class="overlay"></div>
                <div class="wrapper">
                    <div class="featured-content-wrapper">
                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                        </header>

                        <div class="entry-content">
                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                        </div><!-- .entry-content-->

                        <div class="read-more">
                            <?php if( !empty( $btn_label ) ): ?>
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn primary"><?php echo esc_html( $btn_label ); ?></a>
                            <?php endif; ?>
                            <?php if( !empty( $options['slider_alt_btn_url_'. $i] ) && !empty( $options['slider_alt_btn_'. $i] ) ): ?>
                                <a href="<?php echo esc_html( $options['slider_alt_btn_url_'. $i] ); ?>" class="btn"><?php echo esc_html( $options['slider_alt_btn_'. $i] ); ?></a>
                            <?php endif; ?>
                        </div><!-- .read-more -->
                    </div><!-- .featured-content-wrapper -->
                </div><!-- .wrapper -->
            </article>

            <?php $i++; endforeach; ?>

        </div><!-- #businesszen_featured_slider_section -->   

    <?php }
endif;