<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Businesszen
 * @since Businesszen 1.0.0
 */

$options = businesszen_get_theme_options();


if ( ! function_exists( 'businesszen_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Businesszen 1.0.0
	 */
	function businesszen_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'businesszen_doctype', 'businesszen_doctype', 10 );


if ( ! function_exists( 'businesszen_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Businesszen 1.0.0
	 *
	 */
	function businesszen_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">

		<link rel="profile" href="https://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php echo esc_url( get_bloginfo( 'pingback_url' ) ); ?>">
		<?php endif;
	}
endif;
add_action( 'businesszen_before_wp_head', 'businesszen_head', 10 );

if ( ! function_exists( 'businesszen_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Businesszen 1.0.0
	 *
	 */
	function businesszen_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'businesszen' ); ?></a>

		<?php
	}
endif;
add_action( 'businesszen_page_start_action', 'businesszen_page_start', 10 );

if ( ! function_exists( 'businesszen_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Businesszen 1.0.0
	 *
	 */
	function businesszen_header_start() {
		$options = businesszen_get_theme_options();
		?>
		<div class="menu-overlay"></div>

		<?php if( $options['topbar_section_enable'] == true ){ ?>

		<div id="top-bar" class="relative">
			<div class="wrapper">
				<div class="col-2 clear">
					<div class="hentry">
						<ul class="contact-info clear">
							<?php if( !empty( $options['topbar_no'] ) ): ?>
								<li class="number"><a href="tel:<?php echo esc_attr( $options['topbar_no'] ); ?>">
									<?php echo businesszen_get_svg( array( 'icon' => 'phone' ) ); ?>
									<span><?php echo esc_html( $options['topbar_no'] ); ?></span></a>
								</li>
							<?php endif; 
							if( !empty( $options['topbar_email'] ) ):
								?>
							<li class="email"><a href="mailto:<?php echo esc_attr( $options['topbar_email'] ); ?>">
								<?php echo businesszen_get_svg( array( 'icon' => 'envelope' ) ); ?>
								<span><?php echo esc_html( $options['topbar_email'] ); ?></span></a>
							</li>
						<?php endif; 
						if( !empty( $options['topbar_location'] ) ):
							?>
						<li class="location">
							<?php echo businesszen_get_svg( array( 'icon' => 'location' ) ); ?>
							<span><?php echo esc_html( $options['topbar_location'] ); ?></span>
						</li>
					<?php endif; ?>
				</ul><!-- .contact-info -->
			</div><!-- .hentry -->

			<div class="hentry">
				<div class="secondary-menu">
			<?php 
			if( $options['topbar_social_menu_enable'] && has_nav_menu( 'social' )): ?>
					<?php 
					wp_nav_menu(  array(
						'theme_location' => 'social',
						'container' => 'div',
						'container_class' => 'social-icons',
						'echo' => true,
						'depth' => 1,
						'link_before' => '<span class="screen-reader-text">',
						'link_after' => '</span>',
						'fallback_cb' => false,
						) );
						?>
				<?php
				endif;
				?>
					</div>
				</div>
			</div><!-- .col-2 -->
		</div><!-- .wrapper -->
	</div><!-- #top-bar -->

	<?php	} ?>		
		
		<header id="masthead" class="site-header" role="banner">
		<div class="wrapper">
		<?php
	}
endif;
add_action( 'businesszen_header_action', 'businesszen_header_start', 20 );

if ( ! function_exists( 'businesszen_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Businesszen 1.0.0
	 *
	 */
	function businesszen_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'businesszen_page_end_action', 'businesszen_page_end', 10 );

if ( ! function_exists( 'businesszen_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Businesszen 1.0.0
	 *
	 */
	function businesszen_site_branding() {
		$options  = businesszen_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>
		
		
		<div class="site-branding">
			<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
				<div class="site-logo">
					<?php the_custom_logo(); ?>
				</div>
			<?php } 
			if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
				<div id="site-identity">
					<?php
					if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
						if ( businesszen_is_latest_posts() || businesszen_is_frontpage() ) : ?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<?php else : ?>
							<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
						<?php
						endif;
					} 
					if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
						$description = get_bloginfo( 'description', 'display' );
						if ( $description || is_customize_preview() ) : ?>
							<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
						<?php
						endif; 
					}?>
				</div>
			<?php endif; ?>
		</div><!-- .site-branding -->
		
		<?php
	}
endif;
add_action( 'businesszen_header_action', 'businesszen_site_branding', 20 );

if ( ! function_exists( 'businesszen_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Businesszen 1.0.0
	 *
	 */
	function businesszen_site_navigation() {
		$options = businesszen_get_theme_options();
		?>
		
		<nav id="site-navigation" class="main-navigation" role="navigation" aria-label="Primary Menu">
			<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
				<?php
				echo businesszen_get_svg( array( 'icon' => 'menu' ) );
				echo businesszen_get_svg( array( 'icon' => 'close' ) );
				?>	
				<span class="menu-label"><?php esc_html_e('Menu', 'businesszen'); ?></span>
			</button>

			<?php

			$search = '';
				$search = '<li class="search-menu"><a href="#" class="">';
			$search .= businesszen_get_svg( array( 'icon' => 'search' ) );
			$search .= businesszen_get_svg( array( 'icon' => 'close' ) );
			$search .= '</a><div id="search" style="display: none;">';
			$search .= get_search_form( $echo = false );
			$search .= '</div></li>';

			wp_nav_menu( array(
				'theme_location' => 'primary',
				'container' => 'div',
				'menu_class' => 'menu nav-menu',
				'menu_id' => 'primary-menu',
				'echo' => true,
				'fallback_cb' => 'businesszen_menu_fallback_cb',
				'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s'  . $search . '</ul>',
				) );
				?>

	</nav><!-- .main-navigation-->

		<?php
	}
endif;
add_action( 'businesszen_header_action', 'businesszen_site_navigation', 30 );


if ( ! function_exists( 'businesszen_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Businesszen 1.0.0
	 *
	 */
	function businesszen_header_end() {
		?>
</div><!-- .wrapper -->
</header><!-- #masthead -->
		<?php
	}
endif;

add_action( 'businesszen_header_action', 'businesszen_header_end', 50 );

if ( ! function_exists( 'businesszen_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Businesszen 1.0.0
	 *
	 */
	function businesszen_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'businesszen_content_start_action', 'businesszen_content_start', 10 );

if ( ! function_exists( 'businesszen_header_image' ) ) :
	/**
	 * Header Image codes
	 *
	 * @since Businesszen 1.0.0
	 *
	 */
	function businesszen_header_image() {
		$options  = businesszen_get_theme_options();
		if ( businesszen_is_frontpage() )
			return;
		$header_image = get_header_image();
		
		?>
		<?php if ( is_404() || is_search() ): ?>
    		<div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
	            <div class="overlay"></div>
	            <div class="header-wrapper">
		            <div class="wrapper">
		                <header class="page-header">
		                    <?php echo businesszen_custom_header_banner_title(); ?>
		                </header>
		                <?php businesszen_add_breadcrumb(); ?>
		            </div><!-- .wrapper -->
	            </div><!-- .header-wrapper -->
	        </div><!-- #page-site-header -->
    	<?php endif ?>
    	<?php if ( is_singular() && $options['single_post_hide_banner'] == false ): ?>
    		<div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
	    		
	            <div class="overlay"></div>
	            <div class="header-wrapper">
		            <div class="wrapper">
		                <header class="page-header">
		                    <?php echo businesszen_custom_header_banner_title(); ?>
		                </header>

		                <?php businesszen_add_breadcrumb(); ?>
		            </div><!-- .wrapper -->
	            </div><!-- .header-wrapper -->
	        </div><!-- #page-site-header -->
    	<?php endif ?>
    	<?php if (is_singular() && $options['single_post_hide_banner'] == true): ?>
    		<div class="header-wrapper wrapper">
                <header class="page-header">
                    <?php echo businesszen_custom_header_banner_title(); ?>
                </header>

                <?php businesszen_add_breadcrumb(); ?>
            </div><!-- .header-wrapper -->
    	<?php endif ?>

    	<?php if ( ( is_archive() || is_home() ) && $options['hide_banner'] == false ): ?>
    		<div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
	    		
	            <div class="overlay"></div>
	            <div class="header-wrapper">
		            <div class="wrapper">
		                <header class="page-header">
		                    <?php echo businesszen_custom_header_banner_title(); ?>
		                </header>

		                <?php businesszen_add_breadcrumb(); ?>
		            </div><!-- .wrapper -->
	            </div><!-- .header-wrapper -->
	        </div><!-- #page-site-header -->
    	<?php endif ?>
    	<?php if ( ( is_archive() || is_home() ) && $options['hide_banner'] == true): ?>
    		<div class="header-wrapper wrapper">
                <header class="page-header">
                    <?php echo businesszen_custom_header_banner_title(); ?>
                </header>

                <?php businesszen_add_breadcrumb(); ?>
            </div><!-- .header-wrapper -->
    	<?php endif ?>

    	

	<?php
	}
endif;
add_action( 'businesszen_header_image_action', 'businesszen_header_image', 10 );

if ( ! function_exists( 'businesszen_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since Businesszen 1.0.0
	 */
	function businesszen_add_breadcrumb() {
		$options = businesszen_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( businesszen_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * businesszen_simple_breadcrumb hook
				 *
				 * @hooked businesszen_simple_breadcrumb -  10
				 *
				 */
				do_action( 'businesszen_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
		return;
	}
endif;

if ( ! function_exists( 'businesszen_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Businesszen 1.0.0
	 *
	 */
	function businesszen_content_end() {
		?>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'businesszen_content_end_action', 'businesszen_content_end', 10 );

if ( ! function_exists( 'businesszen_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Businesszen 1.0.0
	 *
	 */
	function businesszen_footer_start() {

		$options = businesszen_get_theme_options();
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
		
		<?php
	}
endif;
add_action( 'businesszen_footer', 'businesszen_footer_start', 10 );

if ( ! function_exists( 'businesszen_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Businesszen 1.0.0
	 *
	 */
	function businesszen_footer_site_info() {
		$options = businesszen_get_theme_options();
		$theme_data = wp_get_theme();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text = $options['copyright_text'] ? $options['copyright_text'] : '';
		?>
		
			
		<div class="site-info">
            <div class="wrapper">
                <span>
                <?php if ( !empty( $copyright_text ) ): ?>
                	<?php if ( !empty( $copyright_text ) ):
				echo businesszen_santize_allow_tag( $copyright_text );
				endif; ?>
			<?php endif; ?>
				<?php echo esc_html__( ' All Rights Reserved | ', 'businesszen' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'businesszen' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>' ?>
                </span>
            </div><!-- .wrapper -->    
        </div><!-- .site-info -->

		

		<?php
	}
endif;
add_action( 'businesszen_footer', 'businesszen_footer_site_info', 40 );

if ( ! function_exists( 'businesszen_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Businesszen 1.0.0
	 *
	 */
	function businesszen_footer_scroll_to_top() {
		$options  = businesszen_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo businesszen_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'businesszen_footer', 'businesszen_footer_scroll_to_top', 40 );

if ( ! function_exists( 'businesszen_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Businesszen 1.0.0
	 *
	 */
	function businesszen_footer_end() {
		?>
		</footer>
		<div class="popup-overlay"></div>
		<?php
	}
endif;
add_action( 'businesszen_footer', 'businesszen_footer_end', 100 );

if ( ! function_exists( 'businesszen_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Businesszen 1.0.0
	 *
	 */
	function businesszen_loader() {
		$options = businesszen_get_theme_options();
		?>
			<div id="loader">
            <div class="loader-container">
	                <div id="preloader">
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                </div>
            </div>
        </div><!-- #loader -->
		<?php }
endif;
add_action( 'businesszen_before_header', 'businesszen_loader', 10 );

if ( ! function_exists( 'businesszen_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since Businesszen 1.0.0
	 *
	 */
	function businesszen_infinite_loader_spinner() { 
		global $post;
		$options = businesszen_get_theme_options();
		if ( $options['pagination_type'] == 'infinite' ) :
			if ( count( $post ) > 0 ) {
				echo '<div class="blog-loader">' . businesszen_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';
			}
		endif;
	}
endif;
add_action( 'businesszen_infinite_loader_spinner_action', 'businesszen_infinite_loader_spinner', 10 );